aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorNassim Jahnke <[email protected]>2024-02-01 11:41:29 +0100
committerNassim Jahnke <[email protected]>2024-02-01 11:41:29 +0100
commit8bc5be8ba726a10c2d2e4a1b0fd500d027c08988 (patch)
tree9e735ace9410964db64e17b089e2875c94e4c915
parent7f856a1d1f61a0dea7d4cd2ea60fae3d0c2ad18d (diff)
downloadPaper-8bc5be8ba726a10c2d2e4a1b0fd500d027c08988.tar.gz
Paper-8bc5be8ba726a10c2d2e4a1b0fd500d027c08988.zip
Add missing catch
-rw-r--r--patches/server/0013-Paper-Plugins.patch8
1 files changed, 5 insertions, 3 deletions
diff --git a/patches/server/0013-Paper-Plugins.patch b/patches/server/0013-Paper-Plugins.patch
index 2f56d5a571..0bc8990f58 100644
--- a/patches/server/0013-Paper-Plugins.patch
+++ b/patches/server/0013-Paper-Plugins.patch
@@ -5480,10 +5480,10 @@ index 0000000000000000000000000000000000000000..49a087381307eab263f7dad43aaa2598
+}
diff --git a/src/main/java/io/papermc/paper/plugin/provider/source/DirectoryProviderSource.java b/src/main/java/io/papermc/paper/plugin/provider/source/DirectoryProviderSource.java
new file mode 100644
-index 0000000000000000000000000000000000000000..3185c91e859013d0a222cc5a559e30c4bd9da84a
+index 0000000000000000000000000000000000000000..162c8ce2cb5e5863ea88c1bfbe90ab45288b50e4
--- /dev/null
+++ b/src/main/java/io/papermc/paper/plugin/provider/source/DirectoryProviderSource.java
-@@ -0,0 +1,65 @@
+@@ -0,0 +1,67 @@
+package io.papermc.paper.plugin.provider.source;
+
+import com.mojang.logging.LogUtils;
@@ -5518,6 +5518,8 @@ index 0000000000000000000000000000000000000000..3185c91e859013d0a222cc5a559e30c4
+ this.walkFiles(context, path -> {
+ try {
+ super.prepareContext(path);
++ } catch (IllegalArgumentException ignored) {
++ // Ignore illegal argument exceptions from jar checking
+ } catch (IOException e) {
+ throw new RuntimeException(e);
+ }
@@ -5531,7 +5533,7 @@ index 0000000000000000000000000000000000000000..3185c91e859013d0a222cc5a559e30c4
+ try {
+ super.registerProviders(entrypointHandler, path);
+ } catch (IllegalArgumentException ignored) {
-+ // Ignore initial argument exceptions
++ // Ignore illegal argument exceptions from jar checking
+ } catch (Exception e) {
+ LOGGER.error("Error loading plugin: " + e.getMessage(), e);
+ }